==> camel-k-model-v1alpha1-6.4.0-sources.jar: io/fabric8/camelk/v1alpha1/KameletStatusFluentImpl.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KameletStatusFluentImpl<A extends KameletStatusFluent<A>> extends BaseFluent<A> implements KameletStatusFluent<A>{
  public KameletStatusFluentImpl() {
  }
  public KameletStatusFluentImpl(KameletStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withPhase(instance.getPhase()); 
    this.withProperties(instance.getProperties()); 
  }
  private ArrayList<KameletConditionBuilder> conditions = new ArrayList<KameletConditionBuilder>();
  private String phase;
  private ArrayList<KameletPropertyBuilder> properties = new ArrayList<KameletPropertyBuilder>();
  public A addToConditions(Integer index,KameletCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(Integer index,KameletCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    KameletConditionBuilder builder = new KameletConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(Collection<KameletCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items) {
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<KameletCondition> items) {
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(Predicate<KameletConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<KameletConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      KameletConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletCondition> getConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public List<KameletCondition> buildConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public KameletCondition buildCondition(Integer index) {
    return this.conditions.get(index).build();
  }
  public KameletCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public KameletCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public KameletCondition buildMatchingCondition(Predicate<KameletConditionBuilder> predicate) {
    for (KameletConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<KameletConditionBuilder> predicate) {
    for (KameletConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<KameletCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new ArrayList(); for (KameletCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.camelk.v1alpha1.KameletCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (KameletCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public KameletStatusFluent.ConditionsNested<A> addNewCondition() {
    return new KameletStatusFluentImpl.ConditionsNestedImpl();
  }
  public KameletStatusFluent.ConditionsNested<A> addNewConditionLike(KameletCondition item) {
    return new KameletStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public KameletStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,KameletCondition item) {
    return new KameletStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public KameletStatusFluent.ConditionsNested<A> editCondition(Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public KameletStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public KameletStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public KameletStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<KameletConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public Boolean hasPhase() {
    return this.phase != null;
  }
  public A addToProperties(Integer index,KameletProperty item) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").add(index >= 0 ? index : _visitables.get("properties").size(), builder);this.properties.add(index >= 0 ? index : properties.size(), builder); return (A)this;
  }
  public A setToProperties(Integer index,KameletProperty item) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    KameletPropertyBuilder builder = new KameletPropertyBuilder(item);
    if (index < 0 || index >= _visitables.get("properties").size()) { _visitables.get("properties").add(builder); } else { _visitables.get("properties").set(index, builder);}
    if (index < 0 || index >= properties.size()) { properties.add(builder); } else { properties.set(index, builder);}
     return (A)this;
  }
  public A addToProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").add(builder);this.properties.add(builder);} return (A)this;
  }
  public A addAllToProperties(Collection<KameletProperty> items) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").add(builder);this.properties.add(builder);} return (A)this;
  }
  public A removeFromProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items) {
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").remove(builder);if (this.properties != null) {this.properties.remove(builder);}} return (A)this;
  }
  public A removeAllFromProperties(Collection<KameletProperty> items) {
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").remove(builder);if (this.properties != null) {this.properties.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromProperties(Predicate<KameletPropertyBuilder> predicate) {
    if (properties == null) return (A) this;
    final Iterator<KameletPropertyBuilder> each = properties.iterator();
    final List visitables = _visitables.get("properties");
    while (each.hasNext()) {
      KameletPropertyBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildProperties instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletProperty> getProperties() {
    return properties != null ? build(properties) : null;
  }
  public List<KameletProperty> buildProperties() {
    return properties != null ? build(properties) : null;
  }
  public KameletProperty buildProperty(Integer index) {
    return this.properties.get(index).build();
  }
  public KameletProperty buildFirstProperty() {
    return this.properties.get(0).build();
  }
  public KameletProperty buildLastProperty() {
    return this.properties.get(properties.size() - 1).build();
  }
  public KameletProperty buildMatchingProperty(Predicate<KameletPropertyBuilder> predicate) {
    for (KameletPropertyBuilder item: properties) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingProperty(Predicate<KameletPropertyBuilder> predicate) {
    for (KameletPropertyBuilder item: properties) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withProperties(List<KameletProperty> properties) {
    if (this.properties != null) { _visitables.get("properties").removeAll(this.properties);}
    if (properties != null) {this.properties = new ArrayList(); for (KameletProperty item : properties){this.addToProperties(item);}} else { this.properties = null;} return (A) this;
  }
  public A withProperties(io.fabric8.camelk.v1alpha1.KameletProperty... properties) {
    if (this.properties != null) {this.properties.clear();}
    if (properties != null) {for (KameletProperty item :properties){ this.addToProperties(item);}} return (A) this;
  }
  public Boolean hasProperties() {
    return properties != null && !properties.isEmpty();
  }
  public A addNewProperty(String _default,String name) {
    return (A)addToProperties(new KameletProperty(_default, name));
  }
  public KameletStatusFluent.PropertiesNested<A> addNewProperty() {
    return new KameletStatusFluentImpl.PropertiesNestedImpl();
  }
  public KameletStatusFluent.PropertiesNested<A> addNewPropertyLike(KameletProperty item) {
    return new KameletStatusFluentImpl.PropertiesNestedImpl(-1, item);
  }
  public KameletStatusFluent.PropertiesNested<A> setNewPropertyLike(Integer index,KameletProperty item) {
    return new KameletStatusFluentImpl.PropertiesNestedImpl(index, item);
  }
  public KameletStatusFluent.PropertiesNested<A> editProperty(Integer index) {
    if (properties.size() <= index) throw new RuntimeException("Can't edit properties. Index exceeds size.");
    return setNewPropertyLike(index, buildProperty(index));
  }
  public KameletStatusFluent.PropertiesNested<A> editFirstProperty() {
    if (properties.size() == 0) throw new RuntimeException("Can't edit first properties. The list is empty.");
    return setNewPropertyLike(0, buildProperty(0));
  }
  public KameletStatusFluent.PropertiesNested<A> editLastProperty() {
    int index = properties.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last properties. The list is empty.");
    return setNewPropertyLike(index, buildProperty(index));
  }
  public KameletStatusFluent.PropertiesNested<A> editMatchingProperty(Predicate<KameletPropertyBuilder> predicate) {
    int index = -1;
    for (int i=0;i<properties.size();i++) { 
    if (predicate.test(properties.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching properties. No match found.");
    return setNewPropertyLike(index, buildProperty(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KameletStatusFluentImpl that = (KameletStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
    if (properties != null ? !properties.equals(that.properties) :that.properties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  phase,  properties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (properties != null && !properties.isEmpty()) { sb.append("properties:"); sb.append(properties); }
    sb.append("}");
    return sb.toString();
  }
  class ConditionsNestedImpl<N> extends KameletConditionFluentImpl<KameletStatusFluent.ConditionsNested<N>> implements KameletStatusFluent.ConditionsNested<N>,Nested<N>{
    ConditionsNestedImpl(Integer index,KameletCondition item) {
      this.index = index;
      this.builder = new KameletConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new KameletConditionBuilder(this);
    }
    KameletConditionBuilder builder;
    Integer index;
    public N and() {
      return (N) KameletStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  class PropertiesNestedImpl<N> extends KameletPropertyFluentImpl<KameletStatusFluent.PropertiesNested<N>> implements KameletStatusFluent.PropertiesNested<N>,Nested<N>{
    PropertiesNestedImpl(Integer index,KameletProperty item) {
      this.index = index;
      this.builder = new KameletPropertyBuilder(this, item);
    }
    PropertiesNestedImpl() {
      this.index = -1;
      this.builder = new KameletPropertyBuilder(this);
    }
    KameletPropertyBuilder builder;
    Integer index;
    public N and() {
      return (N) KameletStatusFluentImpl.this.setToProperties(index,builder.build());
    }
    public N endProperty() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1alpha1-6.7.2-sources.jar: io/fabric8/camelk/v1alpha1/KameletStatusFluentImpl.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KameletStatusFluentImpl<A extends KameletStatusFluent<A>> extends BaseFluent<A> implements KameletStatusFluent<A>{
  public KameletStatusFluentImpl() {
  }
  public KameletStatusFluentImpl(KameletStatus instance) {
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withPhase(instance.getPhase());
      this.withProperties(instance.getProperties());
    }
  }
  private ArrayList<KameletConditionBuilder> conditions = new ArrayList<KameletConditionBuilder>();
  private String phase;
  private ArrayList<KameletPropertyBuilder> properties = new ArrayList<KameletPropertyBuilder>();
  public A addToConditions(int index,KameletCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    KameletConditionBuilder builder = new KameletConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  public A setToConditions(int index,KameletCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    KameletConditionBuilder builder = new KameletConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  public A addToConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(Collection<KameletCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<KameletConditionBuilder>();}
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items) {
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<KameletCondition> items) {
    for (KameletCondition item : items) {KameletConditionBuilder builder = new KameletConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(Predicate<KameletConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<KameletConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      KameletConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletCondition> getConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public List<KameletCondition> buildConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public KameletCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  public KameletCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public KameletCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public KameletCondition buildMatchingCondition(Predicate<KameletConditionBuilder> predicate) {
    for (KameletConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<KameletConditionBuilder> predicate) {
    for (KameletConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<KameletCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").clear();}
    if (conditions != null) {this.conditions = new ArrayList(); for (KameletCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.camelk.v1alpha1.KameletCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (KameletCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public KameletStatusFluentImpl.ConditionsNested<A> addNewCondition() {
    return new KameletStatusFluentImpl.ConditionsNestedImpl();
  }
  public KameletStatusFluentImpl.ConditionsNested<A> addNewConditionLike(KameletCondition item) {
    return new KameletStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public KameletStatusFluentImpl.ConditionsNested<A> setNewConditionLike(int index,KameletCondition item) {
    return new KameletStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public KameletStatusFluentImpl.ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public KameletStatusFluentImpl.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public KameletStatusFluentImpl.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public KameletStatusFluentImpl.ConditionsNested<A> editMatchingCondition(Predicate<KameletConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public Boolean hasPhase() {
    return this.phase != null;
  }
  public A addToProperties(int index,KameletProperty item) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    KameletPropertyBuilder builder = new KameletPropertyBuilder(item);
    if (index < 0 || index >= properties.size()) { _visitables.get("properties").add(builder); properties.add(builder); } else { _visitables.get("properties").add(index, builder); properties.add(index, builder);}
    return (A)this;
  }
  public A setToProperties(int index,KameletProperty item) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    KameletPropertyBuilder builder = new KameletPropertyBuilder(item);
    if (index < 0 || index >= properties.size()) { _visitables.get("properties").add(builder); properties.add(builder); } else { _visitables.get("properties").set(index, builder); properties.set(index, builder);}
    return (A)this;
  }
  public A addToProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").add(builder);this.properties.add(builder);} return (A)this;
  }
  public A addAllToProperties(Collection<KameletProperty> items) {
    if (this.properties == null) {this.properties = new ArrayList<KameletPropertyBuilder>();}
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").add(builder);this.properties.add(builder);} return (A)this;
  }
  public A removeFromProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items) {
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").remove(builder);if (this.properties != null) {this.properties.remove(builder);}} return (A)this;
  }
  public A removeAllFromProperties(Collection<KameletProperty> items) {
    for (KameletProperty item : items) {KameletPropertyBuilder builder = new KameletPropertyBuilder(item);_visitables.get("properties").remove(builder);if (this.properties != null) {this.properties.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromProperties(Predicate<KameletPropertyBuilder> predicate) {
    if (properties == null) return (A) this;
    final Iterator<KameletPropertyBuilder> each = properties.iterator();
    final List visitables = _visitables.get("properties");
    while (each.hasNext()) {
      KameletPropertyBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildProperties instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletProperty> getProperties() {
    return properties != null ? build(properties) : null;
  }
  public List<KameletProperty> buildProperties() {
    return properties != null ? build(properties) : null;
  }
  public KameletProperty buildProperty(int index) {
    return this.properties.get(index).build();
  }
  public KameletProperty buildFirstProperty() {
    return this.properties.get(0).build();
  }
  public KameletProperty buildLastProperty() {
    return this.properties.get(properties.size() - 1).build();
  }
  public KameletProperty buildMatchingProperty(Predicate<KameletPropertyBuilder> predicate) {
    for (KameletPropertyBuilder item: properties) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingProperty(Predicate<KameletPropertyBuilder> predicate) {
    for (KameletPropertyBuilder item: properties) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withProperties(List<KameletProperty> properties) {
    if (this.properties != null) { _visitables.get("properties").clear();}
    if (properties != null) {this.properties = new ArrayList(); for (KameletProperty item : properties){this.addToProperties(item);}} else { this.properties = null;} return (A) this;
  }
  public A withProperties(io.fabric8.camelk.v1alpha1.KameletProperty... properties) {
    if (this.properties != null) {this.properties.clear(); _visitables.remove("properties"); }
    if (properties != null) {for (KameletProperty item :properties){ this.addToProperties(item);}} return (A) this;
  }
  public Boolean hasProperties() {
    return properties != null && !properties.isEmpty();
  }
  public A addNewProperty(String _default,String name) {
    return (A)addToProperties(new KameletProperty(_default, name));
  }
  public KameletStatusFluentImpl.PropertiesNested<A> addNewProperty() {
    return new KameletStatusFluentImpl.PropertiesNestedImpl();
  }
  public KameletStatusFluentImpl.PropertiesNested<A> addNewPropertyLike(KameletProperty item) {
    return new KameletStatusFluentImpl.PropertiesNestedImpl(-1, item);
  }
  public KameletStatusFluentImpl.PropertiesNested<A> setNewPropertyLike(int index,KameletProperty item) {
    return new KameletStatusFluentImpl.PropertiesNestedImpl(index, item);
  }
  public KameletStatusFluentImpl.PropertiesNested<A> editProperty(int index) {
    if (properties.size() <= index) throw new RuntimeException("Can't edit properties. Index exceeds size.");
    return setNewPropertyLike(index, buildProperty(index));
  }
  public KameletStatusFluentImpl.PropertiesNested<A> editFirstProperty() {
    if (properties.size() == 0) throw new RuntimeException("Can't edit first properties. The list is empty.");
    return setNewPropertyLike(0, buildProperty(0));
  }
  public KameletStatusFluentImpl.PropertiesNested<A> editLastProperty() {
    int index = properties.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last properties. The list is empty.");
    return setNewPropertyLike(index, buildProperty(index));
  }
  public KameletStatusFluentImpl.PropertiesNested<A> editMatchingProperty(Predicate<KameletPropertyBuilder> predicate) {
    int index = -1;
    for (int i=0;i<properties.size();i++) { 
    if (predicate.test(properties.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching properties. No match found.");
    return setNewPropertyLike(index, buildProperty(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KameletStatusFluentImpl that = (KameletStatusFluentImpl) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;

    if (!java.util.Objects.equals(phase, that.phase)) return false;

    if (!java.util.Objects.equals(properties, that.properties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  phase,  properties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (properties != null) { sb.append("properties:"); sb.append(properties); }
    sb.append("}");
    return sb.toString();
  }
  class ConditionsNestedImpl<N> extends KameletConditionFluentImpl<KameletStatusFluentImpl.ConditionsNested<N>> implements KameletStatusFluentImpl.ConditionsNested<N>,Nested<N>{
    ConditionsNestedImpl(int index,KameletCondition item) {
      this.index = index;
      this.builder = new KameletConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new KameletConditionBuilder(this);
    }
    KameletConditionBuilder builder;
    int index;
    public N and() {
      return (N) KameletStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  class PropertiesNestedImpl<N> extends KameletPropertyFluentImpl<KameletStatusFluentImpl.PropertiesNested<N>> implements KameletStatusFluentImpl.PropertiesNested<N>,Nested<N>{
    PropertiesNestedImpl(int index,KameletProperty item) {
      this.index = index;
      this.builder = new KameletPropertyBuilder(this, item);
    }
    PropertiesNestedImpl() {
      this.index = -1;
      this.builder = new KameletPropertyBuilder(this);
    }
    KameletPropertyBuilder builder;
    int index;
    public N and() {
      return (N) KameletStatusFluentImpl.this.setToProperties(index,builder.build());
    }
    public N endProperty() {
      return and();
    }
    
  }
  
}
